package Bundle::Catalyst;

use strict;

our $VERSION = '0.01';

=head1 NAME

Bundle::Catalyst - All Catalyst goodness

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Catalyst'>

=head1 DESCRIPTION

Installs all the Catalyst modules for you.

=head1 CONTENTS

Catalyst

Catalyst::Plugin::Authentication::CDBI

Catalyst::Plugin::Email

Catalyst::Plugin::FillInForm

Catalyst::Plugin::FormValidator

Catalyst::Plugin::I18N

Catalyst::Plugin::Session::FastMmap

Catalyst::Plugin::Static

Catalyst::Model::CDBI

Catalyst::Model::CDBI::CRUD

Catalyst::Model::Plucene

Catalyst::View::REST::XML

Catalyst::View::REST::YAML

Catalyst::View::TT

=head1 AUTHOR

Sebastian Riedel, C<sri@oook.de>

=head1 LICENSE

This library is free software. You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;
